@@ -4,15 +4,21 @@ elements.forEach(element => {
     
     actionString = "/";
     
-    if(element.dataset.controller != null && element.dataset.action != null) {
-        actionString += element.dataset.controller + "/" + element.dataset.action + "/";
+    if(element.dataset.controller != null) {
+        actionString += element.dataset.controller + "/";
         element.removeAttribute("data-controller");
-        element.removeAttribute("data-action");
+
+        if(element.dataset.action != null) {
+            actionString += element.dataset.action + "/";
+            element.removeAttribute("data-action");
+        }
     }
-    else{
-        actionString = "Missing [data-controller] OR [data-action]";
+    else {
+        actionString = "Missing [data-controller] attribute";
     }
 
+    
+
     // Check what element type we are dealing with, to set the correct attribute
     switch(element.nodeName) {
         case "A":
