@@ -74,20 +74,33 @@ def get_decorators(cls):
   return decorators;
 
 def getFunctionArguements(func):
-  full_args = inspect.getfullargspec(func);
-  # 0 = args <list>
-  # 6 = annotations <dict>
-  print(full_args);
+    full_args = inspect.getfullargspec(func);
+    # 0 = args <list>
+    # 6 = annotations <dict>
+    print(full_args);
   
-  routeArguements = "/";
+    routeArguements = "/";
 
-  if bool(full_args[6]) == True: # Not empty
-    for key in full_args[6]:
-      #print("KEY: " + key);
-      #print("VALUE: " + full_args[6][key].__name__);
-      routeArguements += "<" + full_args[6][key].__name__ + ":" + key + ">" + "/";
+    # Get all arguements
+    args_temp = full_args[0];
+
+    for arg in args_temp[:]:
+        # Check if it contains type
+        arg_found = False;
+        for key in full_args[6]:
+            if arg == key:
+                routeArguements += "<" + full_args[6][key].__name__ + ":" + key + ">" + "/";
+                arg_found = True;
+
+        if arg_found == True:
+            args_temp.remove(arg);
+            continue;
+
+        # If it doesnt contain a type
+        routeArguements += "<" + arg + ">" + "/";
+        args_temp.remove(arg);
   
-  return routeArguements;
+    return routeArguements;
 
 def getFunctionMethods(funcName:str, classDecorators:dict):
     methodList = [];
